@@ -1,15 +1,19 @@
 package Log::ger::Output::LogDispatchOutput;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-07'; # DATE
+our $DATE = '2020-03-09'; # DATE
 our $DIST = 'Log-ger-Output-LogDispatchOutput'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
 
 use Log::ger::Util;
 
+sub meta { +{
+    v => 1,
+} }
+
 sub get_hooks {
     my %plugin_conf = @_;
 
@@ -70,7 +74,7 @@ Log::ger::Output::LogDispatchOutput - Send logs to a Log::Dispatch output
 
 =head1 VERSION
 
-This document describes version 0.004 of Log::ger::Output::LogDispatchOutput (from Perl distribution Log-ger-Output-LogDispatchOutput), released on 2020-03-07.
+This document describes version 0.005 of Log::ger::Output::LogDispatchOutput (from Perl distribution Log-ger-Output-LogDispatchOutput), released on 2020-03-09.
 
 =head1 SYNOPSIS
 
